@@ -350,9 +350,18 @@ struct aws_s3_meta_request_options {
      * be used. If not NULL, these options will override the client options. */
     const struct aws_signing_config_aws *signing_config;
 
-    /* Initial HTTP message that defines what operation we are doing. */
+    /* Initial HTTP message that defines what operation we are doing.
+     * When uploading a file, you should set `send_filepath` (instead of the message's body-stream)
+     * for better performance. */
     struct aws_http_message *message;
 
+    /**
+     * Optional.
+     * If set, this file is sent as the request body, and the `message` body-stream is ignored.
+     * This can give better performance than sending data using the body-stream.
+     */
+    struct aws_byte_cursor send_filepath;
+
     /**
      * Optional.
      * if set, the flexible checksum will be performed by client based on the config.
